=== modified file 'drizzled/catalog/instance.h'
--- drizzled/catalog/instance.h	2011-01-24 21:37:43 +0000
+++ drizzled/catalog/instance.h	2011-01-25 20:05:35 +0000
@@ -41,6 +41,7 @@
   drizzled::session_id_t _lock_id;
   message::catalog::shared_ptr _message;
   mutable boost::mutex _schema_lock;
+  mutable boost::mutex _system_variable_lock;
 
 
 public:
@@ -130,6 +131,11 @@
   {
     return _schema_lock;
   }
+
+  boost::mutex &systemVariableLock()
+  {
+    return _system_variable_lock;
+  }
 };
 
 } /* namespace catalog */

=== modified file 'drizzled/drizzled.cc'
--- drizzled/drizzled.cc	2011-01-24 05:33:52 +0000
+++ drizzled/drizzled.cc	2011-01-25 23:29:53 +0000
@@ -229,7 +229,6 @@
 
 /* Global variables */
 
-bool volatile ready_to_exit;
 char *drizzled_user;
 bool volatile select_thread_in_use;
 bool volatile abort_loop;
@@ -338,13 +337,9 @@
 
 SHOW_COMP_OPTION have_symlink;
 
-/* Thread specific variables */
-boost::mutex LOCK_global_system_variables;
-
 boost::condition_variable_any COND_refresh;
 boost::condition_variable COND_thread_count;
 pthread_t signal_thread;
-boost::condition_variable COND_server_end;
 
 /* Static variables */
 
@@ -519,13 +514,8 @@
 
   if (print_message && server_start_time)
     errmsg_printf(ERRMSG_LVL_INFO, _(ER(ER_SHUTDOWN_COMPLETE)),internal::my_progname);
-  {
-    boost::mutex::scoped_lock scopedLock(session::Cache::singleton().mutex());
-    ready_to_exit= true;
 
-    /* do the broadcast inside the lock to ensure that my_end() is not called */
-    COND_server_end.notify_all();
-  }
+  session::Cache::singleton().shutdownFirst();
 
   /*
     The following lines may never be executed as the main thread may have
@@ -2082,7 +2072,7 @@
   getDebug().reset();
   wake_thread=0;
   abort_loop= select_thread_in_use= false;
-  ready_to_exit= shutdown_in_progress= 0;
+  shutdown_in_progress= 0;
   drizzled_user= drizzled_chroot= 0;
   memset(&current_global_counters, 0, sizeof(current_global_counters));
   key_map_full.set();

=== modified file 'drizzled/main.cc'
--- drizzled/main.cc	2011-01-25 17:16:10 +0000
+++ drizzled/main.cc	2011-01-26 01:41:04 +0000
@@ -400,14 +400,7 @@
   COND_thread_count.notify_all();
 
   /* Wait until cleanup is done */
-  {
-    boost::mutex::scoped_lock scopedLock(session::Cache::singleton().mutex());
-
-    while (not ready_to_exit)
-    {
-      COND_server_end.wait(scopedLock);
-    }
-  }
+  session::Cache::singleton().shutdownSecond();
 
   clean_up(1);
   module::Registry::shutdown();

=== modified file 'drizzled/pthread_globals.h'
--- drizzled/pthread_globals.h	2010-12-18 04:43:40 +0000
+++ drizzled/pthread_globals.h	2011-01-25 23:29:53 +0000
@@ -30,15 +30,12 @@
 namespace drizzled
 {
 
-extern boost::mutex LOCK_global_system_variables;
-
 typedef boost::unique_lock<boost::mutex>  boost_unique_lock_t;
 
 typedef boost::shared_ptr<boost::thread> boost_thread_shared_ptr;
 
 extern boost::condition_variable_any COND_refresh;
 extern boost::condition_variable COND_thread_count;
-extern boost::condition_variable COND_server_end;
 extern pthread_t signal_thread;
 
 } /* namespace drizzled */

=== modified file 'drizzled/session/cache.cc'
--- drizzled/session/cache.cc	2011-01-08 21:33:39 +0000
+++ drizzled/session/cache.cc	2011-01-25 23:29:53 +0000
@@ -49,6 +49,26 @@
   return Session::shared_ptr();
 }
 
+void Cache::shutdownFirst()
+{
+  boost::mutex::scoped_lock scopedLock(_mutex);
+  _ready_to_exit= true;
+
+  /* do the broadcast inside the lock to ensure that my_end() is not called */
+  _end.notify_all();
+}
+
+  /* Wait until cleanup is done */
+void Cache::shutdownSecond()
+{
+  boost::mutex::scoped_lock scopedLock(_mutex);
+
+  while (not _ready_to_exit)
+  {
+    _end.wait(scopedLock);
+  }
+}
+
 size_t Cache::count()
 {
   boost::mutex::scoped_lock scopedLock(_mutex);

=== modified file 'drizzled/session/cache.h'
--- drizzled/session/cache.h	2011-01-08 21:33:39 +0000
+++ drizzled/session/cache.h	2011-01-25 23:29:53 +0000
@@ -36,6 +36,11 @@
 public:
   typedef std::list<Session::shared_ptr> list;
 
+  Cache() :
+    _ready_to_exit(false)
+  {
+  }
+
   static inline Cache &singleton()
   {
     static Cache open_cache;
@@ -53,6 +58,14 @@
     return _mutex;
   }
 
+  boost::condition_variable &cond()
+  {
+    return _end;
+  }
+
+  void shutdownFirst();
+  void shutdownSecond();
+
   void erase(Session::shared_ptr&);
   size_t count();
   void insert(Session::shared_ptr &arg);
@@ -60,8 +73,10 @@
   Session::shared_ptr find(const session_id_t &id);
 
 private:
+  bool volatile _ready_to_exit;
   list cache;
   boost::mutex _mutex;
+  boost::condition_variable _end;
 };
 
 } /* namespace session */

=== modified file 'drizzled/sys_var.cc'
--- drizzled/sys_var.cc	2011-01-24 21:05:10 +0000
+++ drizzled/sys_var.cc	2011-01-25 20:05:35 +0000
@@ -474,7 +474,8 @@
 bool sys_var_uint32_t_ptr::update(Session *session, set_var *var)
 {
   uint64_t tmp= var->getInteger();
-  LOCK_global_system_variables.lock();
+  boost::mutex::scoped_lock scopedLock(session->catalog().systemVariableLock());
+
   if (option_limits)
   {
     uint32_t newvalue= (uint32_t) fix_unsigned(session, tmp, option_limits);
@@ -482,26 +483,28 @@
       *value= newvalue;
   }
   else
+  {
     *value= static_cast<uint32_t>(tmp);
-  LOCK_global_system_variables.unlock();
+  }
+
   return 0;
 }
 
 
-void sys_var_uint32_t_ptr::set_default(Session *, sql_var_t)
+void sys_var_uint32_t_ptr::set_default(Session *session, sql_var_t)
 {
   bool not_used;
-  LOCK_global_system_variables.lock();
+  boost::mutex::scoped_lock scopedLock(session->catalog().systemVariableLock());
   *value= (uint32_t)getopt_ull_limit_value((uint32_t) option_limits->def_value,
                                            option_limits, &not_used);
-  LOCK_global_system_variables.unlock();
 }
 
 
 bool sys_var_uint64_t_ptr::update(Session *session, set_var *var)
 {
   uint64_t tmp= var->getInteger();
-  LOCK_global_system_variables.lock();
+  boost::mutex::scoped_lock scopedLock(session->catalog().systemVariableLock());
+
   if (option_limits)
   {
     uint64_t newvalue= fix_unsigned(session, tmp, option_limits);
@@ -509,13 +512,15 @@
       *value= newvalue;
   }
   else
+  {
     *value= tmp;
-  LOCK_global_system_variables.unlock();
+  }
+
   return 0;
 }
 
 
-void sys_var_uint64_t_ptr::set_default(Session *, sql_var_t)
+void sys_var_uint64_t_ptr::set_default(Session *session, sql_var_t)
 {
   if (have_default_value)
   {
@@ -524,10 +529,9 @@
   else
   {
     bool not_used;
-    LOCK_global_system_variables.lock();
+    boost::mutex::scoped_lock scopedLock(session->catalog().systemVariableLock());
     *value= getopt_ull_limit_value((uint64_t) option_limits->def_value,
                                    option_limits, &not_used);
-    LOCK_global_system_variables.unlock();
   }
 }
 
@@ -535,23 +539,24 @@
 bool sys_var_size_t_ptr::update(Session *session, set_var *var)
 {
   size_t tmp= size_t(var->getInteger());
-  LOCK_global_system_variables.lock();
+
+  boost::mutex::scoped_lock scopedLock(session->catalog().systemVariableLock());
+
   if (option_limits)
     *value= fix_size_t(session, tmp, option_limits);
   else
     *value= tmp;
-  LOCK_global_system_variables.unlock();
+
   return 0;
 }
 
 
-void sys_var_size_t_ptr::set_default(Session *, sql_var_t)
+void sys_var_size_t_ptr::set_default(Session *session, sql_var_t)
 {
   bool not_used;
-  LOCK_global_system_variables.lock();
+  boost::mutex::scoped_lock scopedLock(session->catalog().systemVariableLock());
   *value= (size_t)getopt_ull_limit_value((size_t) option_limits->def_value,
                                          option_limits, &not_used);
-  LOCK_global_system_variables.unlock();
 }
 
 bool sys_var_bool_ptr::update(Session *, set_var *var)
@@ -642,12 +647,14 @@
   if (var->type == OPT_GLOBAL)
   {
     /* Lock is needed to make things safe on 32 bit systems */
-    LOCK_global_system_variables.lock();
+    boost::mutex::scoped_lock scopedLock(session->catalog().systemVariableLock());
     global_system_variables.*offset= (ha_rows) tmp;
-    LOCK_global_system_variables.unlock();
   }
   else
+  {
     session->variables.*offset= (ha_rows) tmp;
+  }
+
   return 0;
 }
 
@@ -658,14 +665,15 @@
   {
     bool not_used;
     /* We will not come here if option_limits is not set */
-    LOCK_global_system_variables.lock();
+    boost::mutex::scoped_lock scopedLock(session->catalog().systemVariableLock());
     global_system_variables.*offset=
       (ha_rows) getopt_ull_limit_value((ha_rows) option_limits->def_value,
                                        option_limits, &not_used);
-    LOCK_global_system_variables.unlock();
   }
   else
+  {
     session->variables.*offset= global_system_variables.*offset;
+  }
 }
 
 
@@ -699,12 +707,14 @@
   if (var->type == OPT_GLOBAL)
   {
     /* Lock is needed to make things safe on 32 bit systems */
-    LOCK_global_system_variables.lock();
+    boost::mutex::scoped_lock scopedLock(session->catalog().systemVariableLock());
     global_system_variables.*offset= (uint64_t) tmp;
-    LOCK_global_system_variables.unlock();
   }
   else
+  {
     session->variables.*offset= (uint64_t) tmp;
+  }
+
   return 0;
 }
 
@@ -714,14 +724,15 @@
   if (type == OPT_GLOBAL)
   {
     bool not_used;
-    LOCK_global_system_variables.lock();
+    boost::mutex::scoped_lock scopedLock(session->catalog().systemVariableLock());
     global_system_variables.*offset=
       getopt_ull_limit_value((uint64_t) option_limits->def_value,
                              option_limits, &not_used);
-    LOCK_global_system_variables.unlock();
   }
   else
+  {
     session->variables.*offset= global_system_variables.*offset;
+  }
 }
 
 
@@ -752,12 +763,14 @@
   if (var->type == OPT_GLOBAL)
   {
     /* Lock is needed to make things safe on 32 bit systems */
-    LOCK_global_system_variables.lock();
+    boost::mutex::scoped_lock scopedLock(session->catalog().systemVariableLock());
     global_system_variables.*offset= tmp;
-    LOCK_global_system_variables.unlock();
   }
   else
+  {
     session->variables.*offset= tmp;
+  }
+
   return 0;
 }
 
@@ -767,14 +780,15 @@
   if (type == OPT_GLOBAL)
   {
     bool not_used;
-    LOCK_global_system_variables.lock();
+    boost::mutex::scoped_lock scopedLock(session->catalog().systemVariableLock());
     global_system_variables.*offset=
       (size_t)getopt_ull_limit_value((size_t) option_limits->def_value,
                                      option_limits, &not_used);
-    LOCK_global_system_variables.unlock();
   }
   else
+  {
     session->variables.*offset= global_system_variables.*offset;
+  }
 }
 
 
@@ -794,6 +808,7 @@
     global_system_variables.*offset= bool(var->getInteger());
   else
     session->variables.*offset= bool(var->getInteger());
+
   return 0;
 }
 
@@ -886,56 +901,57 @@
   case SHOW_INT:
   {
     uint32_t value;
-    LOCK_global_system_variables.lock();
+    boost::mutex::scoped_lock scopedLock(session->catalog().systemVariableLock());
     value= *(uint*) value_ptr(session, var_type, base);
-    LOCK_global_system_variables.unlock();
+
     return new Item_uint((uint64_t) value);
   }
   case SHOW_LONGLONG:
   {
     int64_t value;
-    LOCK_global_system_variables.lock();
+    boost::mutex::scoped_lock scopedLock(session->catalog().systemVariableLock());
     value= *(int64_t*) value_ptr(session, var_type, base);
-    LOCK_global_system_variables.unlock();
+
     return new Item_int(value);
   }
   case SHOW_DOUBLE:
   {
     double value;
-    LOCK_global_system_variables.lock();
-    value= *(double*) value_ptr(session, var_type, base);
-    LOCK_global_system_variables.unlock();
+    {
+      boost::mutex::scoped_lock scopedLock(session->catalog().systemVariableLock());
+      value= *(double*) value_ptr(session, var_type, base);
+    }
+
     /* 6, as this is for now only used with microseconds */
     return new Item_float(value, 6);
   }
   case SHOW_HA_ROWS:
   {
     ha_rows value;
-    LOCK_global_system_variables.lock();
+    boost::mutex::scoped_lock scopedLock(session->catalog().systemVariableLock());
     value= *(ha_rows*) value_ptr(session, var_type, base);
-    LOCK_global_system_variables.unlock();
+
     return new Item_int((uint64_t) value);
   }
   case SHOW_SIZE:
   {
     size_t value;
-    LOCK_global_system_variables.lock();
+    boost::mutex::scoped_lock scopedLock(session->catalog().systemVariableLock());
     value= *(size_t*) value_ptr(session, var_type, base);
-    LOCK_global_system_variables.unlock();
+
     return new Item_int((uint64_t) value);
   }
   case SHOW_MY_BOOL:
   {
     int32_t value;
-    LOCK_global_system_variables.lock();
+    boost::mutex::scoped_lock scopedLock(session->catalog().systemVariableLock());
     value= *(bool*) value_ptr(session, var_type, base);
-    LOCK_global_system_variables.unlock();
     return new Item_int(value,1);
   }
   case SHOW_CHAR_PTR:
   {
     Item *tmp;
-    LOCK_global_system_variables.lock();
+    boost::mutex::scoped_lock scopedLock(session->catalog().systemVariableLock());
     char *str= *(char**) value_ptr(session, var_type, base);
     if (str)
     {
@@ -948,13 +964,13 @@
       tmp= new Item_null();
       tmp->collation.set(system_charset_info, DERIVATION_SYSCONST);
     }
-    LOCK_global_system_variables.unlock();
+
     return tmp;
   }
   case SHOW_CHAR:
   {
     Item *tmp;
-    LOCK_global_system_variables.lock();
+    boost::mutex::scoped_lock scopedLock(session->catalog().systemVariableLock());
     char *str= (char*) value_ptr(session, var_type, base);
     if (str)
       tmp= new Item_string(str, strlen(str),
@@ -964,7 +980,7 @@
       tmp= new Item_null();
       tmp->collation.set(system_charset_info, DERIVATION_SYSCONST);
     }
-    LOCK_global_system_variables.unlock();
+
     return tmp;
   }
   default:
@@ -1150,12 +1166,14 @@
   /* We are using Time_zone object found during check() phase. */
   if (var->type == OPT_GLOBAL)
   {
-    LOCK_global_system_variables.lock();
+    boost::mutex::scoped_lock scopedLock(session->catalog().systemVariableLock());
     global_system_variables.time_zone= tmp;
-    LOCK_global_system_variables.unlock();
   }
   else
+  {
     session->variables.time_zone= tmp;
+  }
+
   return 0;
 }
 
@@ -1187,24 +1205,23 @@
 
 void sys_var_session_time_zone::set_default(Session *session, sql_var_t type)
 {
- LOCK_global_system_variables.lock();
- if (type == OPT_GLOBAL)
- {
-   if (default_tz_name)
-   {
-     String str(default_tz_name, &my_charset_utf8_general_ci);
-     /*
-       We are guaranteed to find this time zone since its existence
-       is checked during start-up.
-     */
-     global_system_variables.time_zone= my_tz_find(session, &str);
-   }
-   else
-     global_system_variables.time_zone= my_tz_SYSTEM;
- }
- else
-   session->variables.time_zone= global_system_variables.time_zone;
- LOCK_global_system_variables.unlock();
+  boost::mutex::scoped_lock scopedLock(session->catalog().systemVariableLock());
+  if (type == OPT_GLOBAL)
+  {
+    if (default_tz_name)
+    {
+      String str(default_tz_name, &my_charset_utf8_general_ci);
+      /*
+        We are guaranteed to find this time zone since its existence
+        is checked during start-up.
+      */
+      global_system_variables.time_zone= my_tz_find(session, &str);
+    }
+    else
+      global_system_variables.time_zone= my_tz_SYSTEM;
+  }
+  else
+    session->variables.time_zone= global_system_variables.time_zone;
 }
 
 
@@ -1287,9 +1304,8 @@
   microseconds= (int64_t) (num * 1000000.0 + 0.5);
   if (var->type == OPT_GLOBAL)
   {
-    LOCK_global_system_variables.lock();
+    boost::mutex::scoped_lock scopedLock(session->catalog().systemVariableLock());
     (global_system_variables.*offset)= microseconds;
-    LOCK_global_system_variables.unlock();
   }
   else
     session->variables.*offset= microseconds;
@@ -1302,9 +1318,8 @@
   int64_t microseconds= (int64_t) (option_limits->def_value * 1000000.0);
   if (type == OPT_GLOBAL)
   {
-    LOCK_global_system_variables.lock();
+    boost::mutex::scoped_lock scopedLock(session->catalog().systemVariableLock());
     global_system_variables.*offset= microseconds;
-    LOCK_global_system_variables.unlock();
   }
   else
     session->variables.*offset= microseconds;

=== modified file 'plugin/status_dictionary/status.cc'
--- plugin/status_dictionary/status.cc	2010-12-18 04:43:40 +0000
+++ plugin/status_dictionary/status.cc	2011-01-25 20:05:35 +0000
@@ -95,19 +95,20 @@
   std::ostringstream oss;
   std::string return_value;
 
-  LOCK_global_system_variables.lock();
-
-  if (show_type == SHOW_SYS)
   {
-    show_type= ((sys_var*) value)->show_type();
-    value= (char*) ((sys_var*) value)->value_ptr(&(getSession()), option_type,
-                                                 &null_lex_str);
+    boost::mutex::scoped_lock scopedLock(getSession().catalog().systemVariableLock());
+
+    if (show_type == SHOW_SYS)
+    {
+      show_type= ((sys_var*) value)->show_type();
+      value= (char*) ((sys_var*) value)->value_ptr(&(getSession()), option_type,
+                                                   &null_lex_str);
+    }
+
+    return_value= StatusHelper::fillHelper(NULL, value, show_type); 
   }
-
-  return_value= StatusHelper::fillHelper(NULL, value, show_type); 
-
-  LOCK_global_system_variables.unlock();
   push(name);
+
   if (return_value.length())
     push(return_value);
   else 

=== modified file 'tests/include/diff_tables.inc'
--- tests/include/diff_tables.inc	2010-10-07 21:54:11 +0000
+++ tests/include/diff_tables.inc	2011-01-26 00:31:58 +0000
@@ -55,9 +55,9 @@
 --echo Comparing tables $diff_table_1 and $diff_table_2
 disable_query_log;
 
---error 0,1
+--error EE_OK,EE_ERROR_FIRST
 --remove_file $DRIZZLETEST_VARDIR/tmp/diff_table_1
---error 0,1
+--error EE_OK,EE_ERROR_FIRST
 --remove_file $DRIZZLETEST_VARDIR/tmp/diff_table_2
 
 let $_diff_table=$diff_table_2;

=== modified file 'tests/r/subselect.result'
--- tests/r/subselect.result	2010-12-02 05:09:20 +0000
+++ tests/r/subselect.result	2011-01-26 00:31:58 +0000
@@ -899,9 +899,9 @@
 drop table t1,t2,t3;
 #LIMIT is not supported now
 #create table t1 (a float) ENGINE=MyISAM;
-#-- error 1235
+#--error ER_NOT_SUPPORTED_YET
 #select 10.5 IN (SELECT * from t1 LIMIT 1);
-#-- error 1235
+#--error ER_NOT_SUPPORTED_YET
 #select 10.5 IN (SELECT * from t1 LIMIT 1 UNION SELECT 1.5);
 #drop table t1;
 #
@@ -925,7 +925,7 @@
 #select ROW(1, 1, 'a') IN (select a,b,c from t1 where c='b' or c='a');
 #select ROW(1, 2, 'a') IN (select a,b,c from t1 where c='b' or c='a');
 #select ROW(1, 1, 'a') IN (select b,a,c from t1 where c='b' or c='a');
-#-- error 1235
+#--error ER_NOT_SUPPORTED_YET
 #select ROW(1, 1, 'a') IN (select b,a,c from t1 limit 2);
 #drop table t1;
 #test of uncacheable subqueries
@@ -1330,9 +1330,9 @@
 #CREATE TABLE t1 (s1 CHAR(5) COLLATE latin1_german1_ci,
 #                 s2 CHAR(5) COLLATE latin1_swedish_ci) ENGINE=MyISAM;
 #INSERT INTO t1 VALUES ('z','?');
-#-- error 1267
+#--error ER_CANT_AGGREGATE_2COLLATIONS
 #select * from t1 where s1 > (select max(s2) from t1);
-#-- error 1267
+#--error ER_CANT_AGGREGATE_2COLLATIONS
 #select * from t1 where s1 > any (select max(s2) from t1);
 #drop table t1;
 #

=== modified file 'tests/t/create.test'
--- tests/t/create.test	2011-01-13 23:37:19 +0000
+++ tests/t/create.test	2011-01-26 00:31:58 +0000
@@ -40,7 +40,7 @@
 --error ER_WRONG_AUTO_KEY
 create temporary table t1 (ordid int not null auto_increment, ord  varchar(50) not null, primary key (ord,ordid)) engine=MEMORY;
 
--- error 1049
+-- error ER_BAD_DB_ERROR
 create table not_existing_database.test (a int);
 create table `a/a` (a int);
 --replace_regex /ENGINE=[a-zA-Z]+/ENGINE=DEFAULT/

=== modified file 'tests/t/delete.test'
--- tests/t/delete.test	2010-04-05 23:46:43 +0000
+++ tests/t/delete.test	2011-01-26 00:31:58 +0000
@@ -109,7 +109,7 @@
 select * from t11;
 --sorted_result
 select * from t12;
--- error 1242
+--error ER_SUBQUERY_NO_1_ROW
 delete from t11 where t11.b <> (select b from t2 where t11.a < t2.a);
 select * from t11;
 

=== modified file 'tests/t/derived.test'
--- tests/t/derived.test	2010-08-26 21:56:15 +0000
+++ tests/t/derived.test	2011-01-26 00:31:58 +0000
@@ -4,9 +4,9 @@
 --enable_warnings
 
 select * from (select 2) b;
--- error 1054
+--error ER_BAD_FIELD_ERROR
 SELECT 1 as a FROM (SELECT 1 UNION SELECT a) b;
--- error 1054
+--error ER_BAD_FIELD_ERROR
 SELECT 1 as a FROM (SELECT a UNION SELECT 1) b;
 CREATE TABLE t1 (a int not null, b char (10) not null);
 insert into t1 values(1,'a'),(2,'b'),(3,'c'),(3,'c');
@@ -105,9 +105,9 @@
 #
 create table t1 (a int);
 insert into t1 values (1),(2),(3);
--- error 1064
+--error ER_PARSE_ERROR
 delete from (select * from t1);
--- error 1064
+--error ER_PARSE_ERROR
 insert into  (select * from t1) values (5);
 drop table t1;
 

=== modified file 'tests/t/drizzledump_restore.test'
--- tests/t/drizzledump_restore.test	2011-01-24 04:22:18 +0000
+++ tests/t/drizzledump_restore.test	2011-01-26 00:31:58 +0000
@@ -114,9 +114,9 @@
 DROP DATABASE drizzledump_test;
 
 --echo Ensure we don't have those tables (verify we restored something)
---ERROR 1146
+--ERROR ER_NO_SUCH_TABLE
 SELECT * FROM test.t1;
---ERROR 1146
+--ERROR ER_NO_SUCH_TABLE
 SELECT * FROM drizzledump_test.t1;
 
 --echo Restoring from dumpfile

=== modified file 'tests/t/group_by.test'
--- tests/t/group_by.test	2010-08-26 21:56:15 +0000
+++ tests/t/group_by.test	2011-01-26 00:31:58 +0000
@@ -7,7 +7,7 @@
 #
 # Simple test without tables
 
--- error 1111
+--error ER_INVALID_GROUP_FUNC_USE
 SELECT 1 FROM (SELECT 1) as a  GROUP BY SUM(1);
 
 #

=== modified file 'tests/t/having.test'
--- tests/t/having.test	2010-08-26 21:56:15 +0000
+++ tests/t/having.test	2011-01-26 00:31:58 +0000
@@ -352,7 +352,7 @@
 
 select count(s1) from t1 group by s1 having s1*0=0;
 
--- error 1052
+--error ER_NON_UNIQ_ERROR
 select * from t1 a, t1 b group by a.s1 having s1 is null;
 # ANSI requires: 0 rows
 # MySQL returns:

=== modified file 'tests/t/insert.test'
--- tests/t/insert.test	2011-01-21 01:09:12 +0000
+++ tests/t/insert.test	2011-01-26 00:31:58 +0000
@@ -51,9 +51,9 @@
 #
 
 create table t1 (id int NOT NULL DEFAULT 8);
--- error 1048
+--error ER_BAD_NULL_ERROR
 insert into t1 values(NULL);
--- error 1048
+--error ER_BAD_NULL_ERROR
 insert into t1 values (1), (NULL), (2);
 select * from t1;
 drop table t1;

=== modified file 'tests/t/join.test'
--- tests/t/join.test	2011-01-05 07:43:57 +0000
+++ tests/t/join.test	2011-01-26 00:31:58 +0000
@@ -489,29 +489,29 @@
 # Negative tests (tests for errors)
 #--------------------------------------------------------------------
 # works in Oracle - bug
--- error 1052
+--error ER_NON_UNIQ_ERROR
 select * from t1 natural join (t3 cross join t4);
 # works in Oracle - bug
--- error 1052
+--error ER_NON_UNIQ_ERROR
 select * from (t3 cross join t4) natural join t1;
--- error 1052
+--error ER_NON_UNIQ_ERROR
 select * from t1 join (t2, t3) using (b);
--- error 1052
-select * from ((t1 natural join t2), (t3 natural join t4)) natural join t6;
--- error 1052
-select * from ((t1 natural join t2), (t3 natural join t4)) natural join t6;
--- error 1052
+--error ER_NON_UNIQ_ERROR
+select * from ((t1 natural join t2), (t3 natural join t4)) natural join t6;
+--error ER_NON_UNIQ_ERROR
+select * from ((t1 natural join t2), (t3 natural join t4)) natural join t6;
+--error ER_NON_UNIQ_ERROR
 select * from t6 natural join ((t1 natural join t2),  (t3 natural join t4));
--- error 1052
+--error ER_NON_UNIQ_ERROR
 select * from (t1 join t2 on t1.b=t2.b) natural join (t3 natural join t4);
--- error 1052
+--error ER_NON_UNIQ_ERROR
 select * from  (t3 natural join t4) natural join (t1 join t2 on t1.b=t2.b);
 # this one is OK, the next equivalent one is incorrect (bug in Oracle)
--- error 1052
+--error ER_NON_UNIQ_ERROR
 select * from (t3 join (t4 natural join t5) on (b < z))
               natural join
               (t1 natural join t2);
--- error 1052
+--error ER_NON_UNIQ_ERROR
 select * from (t1 natural join t2) natural join (t3 join (t4 natural join t5) on (b < z));
 
 drop table t1;

=== modified file 'tests/t/kill.test'
--- tests/t/kill.test	2011-01-24 04:22:18 +0000
+++ tests/t/kill.test	2011-01-26 00:31:58 +0000
@@ -87,7 +87,8 @@
 kill @id;
 
 connection conn1;
--- error 1053,2013,1104
+#-- error 1053,2013,1104
+--error ER_SERVER_SHUTDOWN, ER_TOO_BIG_SELECT
 reap;
 
 connection default;

=== modified file 'tests/t/overflow.test'
--- tests/t/overflow.test	2010-03-31 05:53:34 +0000
+++ tests/t/overflow.test	2011-01-26 00:31:58 +0000
@@ -1,6 +1,6 @@
 connect (con1,localhost,root,,);
 connection con1;
--- error 1064,1102,1280,1008
+--error ER_DB_DROP_EXISTS,ER_PARSE_ERROR,ER_WRONG_DB_NAME,ER_WRONG_NAME_FOR_INDEX
 drop database AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA;
 
 # End of 4.1 tests

=== modified file 'tests/t/row.test'
--- tests/t/row.test	2010-08-26 21:56:15 +0000
+++ tests/t/row.test	2011-01-26 00:31:58 +0000
@@ -15,7 +15,7 @@
 select row('b',1.5,3) IN (row('b',NULL,3), row('a',1.5,3), row(1,3,3));
 select row('b',1.5,3) IN (row('b',NULL,4), row('a',1.5,3), row(1,3,3));
 select (1,2,(3,4)) IN ((3,2,(3,4)), (1,2,(3,4)));
--- error 1241
+--error ER_OPERAND_COLUMNS
 select row(1,2,row(3,4)) IN (row(3,2,row(3,4)), row(1,2,4));
 select row(1,2,row(3,4)) IN (row(3,2,row(3,4)), row(1,2,row(3,NULL)));
 explain extended select row(1,2,row(3,4)) IN (row(3,2,row(3,4)), row(1,2,row(3,NULL)));
@@ -37,12 +37,12 @@
 SELECT ROW(NULL,2,3)<=>ROW(NULL,2,3);
 SELECT ROW(1,2,ROW(3,4,5))=ROW(1,2,ROW(3,4,5));
 SELECT ROW('test',2,3.33)=ROW('test',2,3.33);
--- error 1241
+--error ER_OPERAND_COLUMNS
 SELECT ROW('test',2,3.33)=ROW('test',2,3.33,4);
 SELECT ROW('test',2,ROW(3,33))=ROW('test',2,ROW(3,33));
 SELECT ROW('test',2,ROW(3,33))=ROW('test',2,ROW(3,3));
 SELECT ROW('test',2,ROW(3,33))=ROW('test',2,ROW(3,NULL));
--- error 1241
+--error ER_OPERAND_COLUMNS
 SELECT ROW('test',2,ROW(3,33))=ROW('test',2,4);
 
 create table t1 ( a int, b int, c int);
@@ -56,15 +56,15 @@
 select ROW(1,2,3) IN(row(a,b,c), row(1,2,3)) from t1;
 drop table t1;
 
--- error 1241
+--error ER_OPERAND_COLUMNS
 select ROW(1,1);
 
 create table t1 (i int);
--- error 1241
+--error ER_OPERAND_COLUMNS
 select 1 from t1 where ROW(1,1);
--- error 1241
+--error ER_OPERAND_COLUMNS
 select count(*) from t1 order by ROW(1,1);
--- error 1241
+--error ER_OPERAND_COLUMNS
 select count(*) from t1 having (1,1) order by i;
 drop table t1;
 

=== modified file 'tests/t/select.test'
--- tests/t/select.test	2010-08-26 21:56:15 +0000
+++ tests/t/select.test	2011-01-26 00:31:58 +0000
@@ -2487,13 +2487,13 @@
 INSERT INTO t1 VALUES (1),(2),(3);
 INSERT INTO t2 VALUES (2);
 INSERT INTO t3 VALUES (3);
--- error 1052
+--error ER_NON_UNIQ_ERROR
 SELECT t1.id,t3.id FROM t1 JOIN t2 ON (t2.id=t1.id) LEFT JOIN t3 USING (id);
--- error 1052
+--error ER_NON_UNIQ_ERROR
 SELECT t1.id,t3.id FROM t1 JOIN t2 ON (t2.notacolumn=t1.id) LEFT JOIN t3 USING (id);
--- error 1052
+--error ER_NON_UNIQ_ERROR
 SELECT id,t3.id FROM t1 JOIN t2 ON (t2.id=t1.id) LEFT JOIN t3 USING (id);
--- error 1052
+--error ER_NON_UNIQ_ERROR
 SELECT id,t3.id FROM (t1 JOIN t2 ON (t2.id=t1.id)) LEFT JOIN t3 USING (id);
 
 drop table t1, t2, t3;

=== modified file 'tests/t/subselect.test'
--- tests/t/subselect.test	2010-08-26 21:56:15 +0000
+++ tests/t/subselect.test	2011-01-26 00:31:58 +0000
@@ -8,28 +8,28 @@
 explain extended SELECT (SELECT 1) UNION SELECT (SELECT 2);
 SELECT (SELECT (SELECT 0 UNION SELECT 0));
 explain extended SELECT (SELECT (SELECT 0 UNION SELECT 0));
--- error 1247
+--error ER_ILLEGAL_REFERENCE
 SELECT (SELECT 1 FROM (SELECT 1) as b HAVING a=1) as a;
--- error 1247
+--error ER_ILLEGAL_REFERENCE
 SELECT (SELECT 1 FROM (SELECT 1) as b HAVING b=1) as a,(SELECT 1 FROM (SELECT 1) as c HAVING a=1) as b;
 SELECT (SELECT 1),MAX(1) FROM (SELECT 1) as a;
--- error 1247
+--error ER_ILLEGAL_REFERENCE
 SELECT (SELECT a) as a;
 EXPLAIN EXTENDED SELECT 1 FROM (SELECT 1 as a) as b  HAVING (SELECT a)=1;
 SELECT 1 FROM (SELECT 1 as a) as b HAVING (SELECT a)=1;
--- error 1054
+--error ER_BAD_FIELD_ERROR
 SELECT (SELECT 1), a;
 SELECT 1 as a FROM (SELECT 1) as b HAVING (SELECT a)=1;
--- error 1054
+--error ER_BAD_FIELD_ERROR
 SELECT 1 FROM (SELECT (SELECT a) b) c;
 SELECT * FROM (SELECT 1 as id) b WHERE id IN (SELECT * FROM (SELECT 1 as id) c ORDER BY id);
--- error 1241
+--error ER_OPERAND_COLUMNS
 SELECT * FROM (SELECT 1) a  WHERE 1 IN (SELECT 1,1);
 SELECT 1 IN (SELECT 1);
 SELECT 1 FROM (SELECT 1 as a) b WHERE 1 IN (SELECT (SELECT a));
--- error ER_BAD_FIELD_ERROR
+--error ER_BAD_FIELD_ERROR
 SELECT (SELECT 1) as a FROM (SELECT 1) b WHERE (SELECT a) IS NULL;
--- error ER_BAD_FIELD_ERROR
+--error ER_BAD_FIELD_ERROR
 SELECT (SELECT 1) as a FROM (SELECT 1) b WHERE (SELECT a) IS NOT NULL;
 SELECT (SELECT 1,2,3) = ROW(1,2,3);
 SELECT (SELECT 1,2,3) = ROW(1,2,1);
@@ -48,7 +48,7 @@
 SELECT (SELECT 1.5,2,'a') = ROW(1.5,'2','a');
 SELECT (SELECT 1.5,'c','a') = ROW(1.5,2,'a');
 
--- error 1241
+--error ER_OPERAND_COLUMNS
 SELECT (SELECT * FROM (SELECT 'test' a,'test' b) a);
 
 SELECT 1 as a,(SELECT a+a) b,(SELECT b);
@@ -60,7 +60,7 @@
 insert into t1 values (2);
 insert into t2 values (1,7),(2,7);
 insert into t4 values (4,8),(3,8),(5,9);
--- error 1247
+--error ER_ILLEGAL_REFERENCE
 select (select a from t1 where t1.a = a1) as a2, (select b from t2 where t2.b=a2) as a1;
 select (select a from t1 where t1.a=t2.a), a from t2;
 select (select a from t1 where t1.a=t2.b), a from t2;
@@ -104,9 +104,9 @@
 explain extended select * from t3 where a >= any (select b from t2);
 select * from t3 where a >= all (select b from t2);
 delete from t2 where a=100;
--- error 1241
+--error ER_OPERAND_COLUMNS
 select * from t3 where a in (select a,b from t2);
--- error 1241
+--error ER_OPERAND_COLUMNS
 select * from t3 where a in (select * from t2);
 insert into t4 values (12,7),(1,7),(10,9),(9,6),(7,6),(3,9),(1,10);
 --echo # empty set
@@ -123,7 +123,7 @@
 select (select a from t1 where t1.a=t2.a union select a from t5 where t5.a=t2.a), a from t2;
 --replace_column 9 #
 explain extended select (select a from t1 where t1.a=t2.a union select a from t5 where t5.a=t2.a), a from t2;
--- error 1242
+--error ER_SUBQUERY_NO_1_ROW
 select (select a from t1 where t1.a=t2.a union all select a from t5 where t5.a=t2.a), a from t2;
 create temporary table t6 (patient_uq int, clinic_uq int, index i1 (clinic_uq)) ENGINE=MyISAM;
 create temporary table t7( uq int primary key, name char(25)) ENGINE=MyISAM;
@@ -133,7 +133,7 @@
 explain extended select * from t6 where exists (select * from t7 where uq = clinic_uq);
 
 --echo # not unique fields
--- error 1052
+--error ER_NON_UNIQ_ERROR
 select * from t1 where a= (select a from t2,t4 where t2.b=t4.b);
 
 --echo # different tipes & group functions
@@ -161,14 +161,14 @@
 INSERT INTO t8 (pseudo,email) VALUES ('2joce1','2test1');
 --replace_column 9 #
 EXPLAIN EXTENDED SELECT pseudo,(SELECT email FROM t8 WHERE pseudo=(SELECT pseudo FROM t8 WHERE pseudo='joce')) FROM t8 WHERE pseudo=(SELECT pseudo FROM t8 WHERE pseudo='joce');
--- error 1241
+--error ER_OPERAND_COLUMNS
 SELECT pseudo FROM t8 WHERE pseudo=(SELECT pseudo,email FROM
 t8 WHERE pseudo='joce');
--- error 1241
+--error ER_OPERAND_COLUMNS
 SELECT pseudo FROM t8 WHERE pseudo=(SELECT * FROM t8 WHERE
 pseudo='joce');
 SELECT pseudo FROM t8 WHERE pseudo=(SELECT pseudo FROM t8 WHERE pseudo='joce');
--- error 1242
+--error ER_SUBQUERY_NO_1_ROW
 SELECT pseudo FROM t8 WHERE pseudo=(SELECT pseudo FROM t8 WHERE pseudo LIKE '%joce%');
 
 drop table if exists t1,t2,t3,t4,t5,t6,t7,t8;
@@ -188,7 +188,7 @@
 SELECT DISTINCT date FROM t1 WHERE date='2002-08-03';
 SELECT (SELECT DISTINCT date FROM t1 WHERE date='2002-08-03');
 SELECT 1 FROM t1 WHERE 1=(SELECT 1 UNION SELECT 1) UNION ALL SELECT 1;
--- error 1242
+--error ER_SUBQUERY_NO_1_ROW
 SELECT 1 FROM t1 WHERE 1=(SELECT 1 UNION ALL SELECT 1) UNION SELECT 1;
 EXPLAIN EXTENDED SELECT 1 FROM t1 WHERE 1=(SELECT 1 UNION SELECT 1);
 drop table t1;
@@ -214,9 +214,9 @@
 INSERT INTO t2 (mot,topic,date,pseudo) VALUES ('joce','40143','2002-10-22','joce'), ('joce','43506','2002-10-22','joce');
 select numeropost as a FROM t1 GROUP BY (SELECT 1 FROM t1 HAVING a=1);
 SELECT numeropost,maxnumrep FROM t1 WHERE exists (SELECT 1 FROM t2 WHERE (mot='joce') AND date >= '2002-10-21' AND t1.numeropost = t2.topic) ORDER BY maxnumrep DESC LIMIT 0, 20;
--- error 1054
+--error ER_BAD_FIELD_ERROR
 SELECT (SELECT 1) as a FROM (SELECT 1 FROM t1 HAVING a=1) b;
--- error 1054
+--error ER_BAD_FIELD_ERROR
 SELECT 1 IN (SELECT 1 FROM t2 HAVING a);
 
 SELECT * from t2 where topic IN (SELECT topic FROM t2 GROUP BY topic);
@@ -245,9 +245,9 @@
 );
 
 INSERT INTO t1 (numeropost,maxnumrep) VALUES (1,0),(2,1);
--- error 1242
+--error ER_SUBQUERY_NO_1_ROW
 select numeropost as a FROM t1 GROUP BY (SELECT 1 FROM t1 HAVING a=1);
--- error 1242
+--error ER_SUBQUERY_NO_1_ROW
 select numeropost as a FROM t1 ORDER BY (SELECT 1 FROM t1 HAVING a=1);
 drop table t1;
 
@@ -259,7 +259,7 @@
 --echo #iftest
 CREATE TEMPORARY TABLE t1 (field char(1) NOT NULL DEFAULT 'b') ENGINE=MyISAM;
 INSERT INTO t1 VALUES ();
--- error 1242
+--error ER_SUBQUERY_NO_1_ROW
 SELECT field FROM t1 WHERE 1=(SELECT 1 UNION ALL SELECT 1 FROM (SELECT 1) a HAVING field='b');
 drop table t1;
 
@@ -272,13 +272,13 @@
   UNIQUE KEY `numreponse` (`numreponse`),
   KEY `pseudo` (`pseudo`,`numeropost`)
 );
--- error 1247
+--error ER_ILLEGAL_REFERENCE
 SELECT (SELECT numeropost FROM t1 HAVING numreponse=a),numreponse FROM (SELECT * FROM t1) as a;
--- error 1054
+--error ER_BAD_FIELD_ERROR
 SELECT numreponse, (SELECT numeropost FROM t1 HAVING numreponse=a) FROM (SELECT * FROM t1) as a;
 SELECT numreponse, (SELECT numeropost FROM t1 HAVING numreponse=1) FROM (SELECT * FROM t1) as a;
 INSERT INTO t1 (numeropost,numreponse,pseudo) VALUES (1,1,'joce'),(1,2,'joce'),(1,3,'test');
--- error 1242
+--error ER_SUBQUERY_NO_1_ROW
 EXPLAIN EXTENDED SELECT numreponse FROM t1 WHERE numeropost='1' AND numreponse=(SELECT 1 FROM t1 WHERE numeropost='1');
 --replace_column 9 #
 EXPLAIN EXTENDED SELECT MAX(numreponse) FROM t1 WHERE numeropost='1';
@@ -297,9 +297,9 @@
 insert into t1 values (0, 10),(1, 11),(2, 12);
 insert into t2 values (1, 21),(2, 22),(3, 23);
 select * from t1;
--- error 1093
+--error ER_UPDATE_TABLE_USED
 update t1 set b= (select b from t1);
--- error 1242
+--error ER_SUBQUERY_NO_1_ROW
 update t1 set b= (select b from t2);
 update t1 set b= (select b from t2 where t1.a = t2.a);
 select * from t1;
@@ -312,9 +312,9 @@
 insert into t2 values (1, 21),(2, 12),(3, 23);
 select * from t1;
 select * from t1 where b = (select b from t2 where t1.a = t2.a);
--- error 1093
+--error ER_UPDATE_TABLE_USED
 delete from t1 where b = (select b from t1);
--- error 1242
+--error ER_SUBQUERY_NO_1_ROW
 delete from t1 where b = (select b from t2);
 delete from t1 where b = (select b from t2 where t1.a = t2.a);
 select * from t1;
@@ -326,9 +326,9 @@
 create table t3 (b int);
 insert into t2 values (1);
 insert into t3 values (1),(2);
--- error 1093
+--error ER_UPDATE_TABLE_USED
 INSERT INTO t1 (x) VALUES ((SELECT x FROM t1));
--- error 1242
+--error ER_SUBQUERY_NO_1_ROW
 INSERT INTO t1 (x) VALUES ((SELECT b FROM t3));
 INSERT INTO t1 (x) VALUES ((SELECT a FROM t2));
 select * from t1;
@@ -340,7 +340,7 @@
 --echo # After this, only data based on old t1 records should have been added.
 INSERT INTO t1 (x) select (SELECT SUM(x)+2 FROM t1) FROM t2;
 select * from t1;
--- error 1054
+--error ER_BAD_FIELD_ERROR
 INSERT INTO t1 (x) VALUES ((SELECT SUM(x) FROM t2));
 INSERT INTO t1 (x) VALUES ((SELECT SUM(a) FROM t2));
 select * from t1;
@@ -357,9 +357,9 @@
 insert into t2 values (1);
 insert into t3 values (1),(2);
 select * from t1;
--- error 1093
+--error ER_UPDATE_TABLE_USED
 replace into t1 (x, y) VALUES ((SELECT x FROM t1), (SELECT a+1 FROM t2));
--- error 1242
+--error ER_SUBQUERY_NO_1_ROW
 replace into t1 (x, y) VALUES ((SELECT a FROM t3), (SELECT a+1 FROM t2));
 replace into t1 (x, y) VALUES ((SELECT a FROM t2), (SELECT a+1 FROM t2));
 select * from t1;
@@ -375,7 +375,7 @@
 select * from t1;
 drop table t1, t2, t3;
 
--- error 1096
+--error ER_NO_TABLES_USED
 SELECT * FROM (SELECT 1) b WHERE 1 IN (SELECT *);
 
 CREATE TABLE t2 (id int default NULL, KEY id (id));
@@ -388,14 +388,14 @@
 EXPLAIN EXTENDED SELECT * FROM t2 WHERE id IN (SELECT 1 UNION SELECT 3);
 SELECT * FROM t2 WHERE id IN (SELECT 5 UNION SELECT 3);
 SELECT * FROM t2 WHERE id IN (SELECT 5 UNION SELECT 2);
--- error 1093
+--error ER_UPDATE_TABLE_USED
 INSERT INTO t2 VALUES ((SELECT * FROM t2));
--- error 1093
+--error ER_UPDATE_TABLE_USED
 INSERT INTO t2 VALUES ((SELECT id FROM t2));
 SELECT * FROM t2;
 CREATE TEMPORARY TABLE t1 (id int default NULL, KEY id (id)) ENGINE=MyISAM;
 INSERT INTO t1 values (1),(1);
--- error 1242
+--error ER_SUBQUERY_NO_1_ROW
 UPDATE t2 SET id=(SELECT * FROM t1);
 drop table t2, t1;
 
@@ -464,9 +464,9 @@
 
 --echo #LIMIT is not supported now
 --echo #create table t1 (a float) ENGINE=MyISAM;
---echo #-- error 1235
+--echo #--error ER_NOT_SUPPORTED_YET
 --echo #select 10.5 IN (SELECT * from t1 LIMIT 1);
---echo #-- error 1235
+--echo #--error ER_NOT_SUPPORTED_YET
 --echo #select 10.5 IN (SELECT * from t1 LIMIT 1 UNION SELECT 1.5);
 --echo #drop table t1;
 --echo #
@@ -490,7 +490,7 @@
 --echo #select ROW(1, 1, 'a') IN (select a,b,c from t1 where c='b' or c='a');
 --echo #select ROW(1, 2, 'a') IN (select a,b,c from t1 where c='b' or c='a');
 --echo #select ROW(1, 1, 'a') IN (select b,a,c from t1 where c='b' or c='a');
---echo #-- error 1235
+--echo #--error ER_NOT_SUPPORTED_YET
 --echo #select ROW(1, 1, 'a') IN (select b,a,c from t1 limit 2);
 --echo #drop table t1;
 
@@ -567,7 +567,7 @@
 --echo #
 --echo # error in IN
 --echo #
--- error 1146
+--error ER_NO_SUCH_TABLE
 select t1.Continent, t2.Name, t2.Population from t1 LEFT JOIN t2 ON t1.Code = t2.Country  where t2.Population IN (select max(t2.Population) AS Population from t2, t1 where t2.Country = t1.Code group by Continent);
 
 --echo #
@@ -638,7 +638,7 @@
 INSERT INTO t1 VALUES (1);
 UPDATE t1 SET i=i+(SELECT MAX(i) FROM (SELECT 1) t) WHERE i=(SELECT MAX(i));
 UPDATE t1 SET i=i+1 WHERE i=(SELECT MAX(i));
--- error 1054
+--error ER_BAD_FIELD_ERROR
 UPDATE t1 SET t.i=i+(SELECT MAX(i) FROM (SELECT 1) t);
 select * from t1;
 drop table t1;
@@ -783,7 +783,7 @@
 create temporary table t2 (s1 int) ENGINE=MyISAM;
 insert into t1 values (1);
 insert into t2 values (1);
--- error 1054
+--error ER_BAD_FIELD_ERROR
 update t1 set  s1 = s1 + 1 where 1 = (select x.s1 as A from t2 WHERE t2.s1 > t1.s1 order by A);
 DROP TABLE t1, t2;
 
@@ -793,9 +793,9 @@
 --echo #CREATE TABLE t1 (s1 CHAR(5) COLLATE latin1_german1_ci,
 --echo #                 s2 CHAR(5) COLLATE latin1_swedish_ci) ENGINE=MyISAM;
 --echo #INSERT INTO t1 VALUES ('z','?');
---echo #-- error 1267
+--echo #--error ER_CANT_AGGREGATE_2COLLATIONS
 --echo #select * from t1 where s1 > (select max(s2) from t1);
---echo #-- error 1267
+--echo #--error ER_CANT_AGGREGATE_2COLLATIONS
 --echo #select * from t1 where s1 > any (select max(s2) from t1);
 --echo #drop table t1;
 
@@ -813,7 +813,7 @@
 --echo # row union
 --echo #
 create table t1 (s1 char(5));
--- error 1241
+--error ER_OPERAND_COLUMNS
 select (select 'a','b' from t1 union select 'a','b' from t1) from t1;
 insert into t1 values ('tttt');
 select * from t1 where ('a','b')=(select 'a','b' from t1 union select 'a','b' from t1);
@@ -892,7 +892,7 @@
 INSERT INTO t1 VALUES (1),(5);
 CREATE TEMPORARY TABLE t2 (id int default NULL) ENGINE=MyISAM;
 INSERT INTO t2 VALUES (2),(6);
--- error 1241
+--error ER_OPERAND_COLUMNS
 select * from t1 where (1,2,6) in (select * from t2);
 DROP TABLE t1,t2;
 
@@ -922,11 +922,11 @@
 --echo #
 create temporary table t1 (s1 int) ENGINE=MyISAM; 
 create temporary table t2 (s1 int) ENGINE=MyISAM;
--- error 1054
+--error ER_BAD_FIELD_ERROR
 select * from t1 where (select count(*) from t2 where t1.s2) = 1;
--- error 1054
+--error ER_BAD_FIELD_ERROR
 select * from t1 where (select count(*) from t2 group by t1.s2) = 1;
--- error 1054
+--error ER_BAD_FIELD_ERROR
 select count(*) from t2 group by t1.s2;
 drop table t1, t2;
 
@@ -1032,7 +1032,7 @@
 create temporary table t1(id int) ENGINE=MyISAM;
 create temporary table t2(id int) ENGINE=MyISAM;
 create temporary table t3(flag int) ENGINE=MyISAM;
--- error 1064
+--error ER_PARSE_ERROR
 select (select * from t3 where id not null) from t1, t2;
 drop table t1,t2,t3;
 
@@ -1121,31 +1121,31 @@
 SELECT a FROM t1 WHERE a <> ALL (SELECT a FROM t1 HAVING a = 2 UNION SELECT a FROM t1 HAVING a = 2);
 --echo # row tests
 --echo # < > >= <= and = ALL/ <> ANY do not support row operation
--- error 1241
+--error ER_OPERAND_COLUMNS
 SELECT a FROM t1 WHERE (1,2) > ANY (SELECT a FROM t1 WHERE b = 2);
--- error 1241
+--error ER_OPERAND_COLUMNS
 SELECT a FROM t1 WHERE a > ANY (SELECT a,2 FROM t1 WHERE b = 2);
--- error 1241
+--error ER_OPERAND_COLUMNS
 SELECT a FROM t1 WHERE (1,2) > ANY (SELECT a,2 FROM t1 WHERE b = 2);
--- error 1241
+--error ER_OPERAND_COLUMNS
 SELECT a FROM t1 WHERE (1,2) > ALL (SELECT a FROM t1 WHERE b = 2);
--- error 1241
+--error ER_OPERAND_COLUMNS
 SELECT a FROM t1 WHERE a > ALL (SELECT a,2 FROM t1 WHERE b = 2);
--- error 1241
+--error ER_OPERAND_COLUMNS
 SELECT a FROM t1 WHERE (1,2) > ALL (SELECT a,2 FROM t1 WHERE b = 2);
--- error 1241
+--error ER_OPERAND_COLUMNS
 SELECT a FROM t1 WHERE (1,2) = ALL (SELECT a,2 FROM t1 WHERE b = 2);
--- error 1241
+--error ER_OPERAND_COLUMNS
 SELECT a FROM t1 WHERE (1,2) <> ANY (SELECT a,2 FROM t1 WHERE b = 2);
 --echo # following should be converted to IN
--- error 1241
+--error ER_OPERAND_COLUMNS
 SELECT a FROM t1 WHERE (1,2) = ANY (SELECT a FROM t1 WHERE b = 2);
--- error 1241
+--error ER_OPERAND_COLUMNS
 SELECT a FROM t1 WHERE a = ANY (SELECT a,2 FROM t1 WHERE b = 2);
 SELECT a FROM t1 WHERE (1,2) = ANY (SELECT a,2 FROM t1 WHERE b = 2);
--- error 1241
+--error ER_OPERAND_COLUMNS
 SELECT a FROM t1 WHERE (1,2) <> ALL (SELECT a FROM t1 WHERE b = 2);
--- error 1241
+--error ER_OPERAND_COLUMNS
 SELECT a FROM t1 WHERE a <> ALL (SELECT a,2 FROM t1 WHERE b = 2);
 SELECT a FROM t1 WHERE (1,2) <> ALL (SELECT a,2 FROM t1 WHERE b = 2);
 SELECT a FROM t1 WHERE (a,1) = ANY (SELECT a,1 FROM t1 WHERE b = 2);
@@ -1315,7 +1315,7 @@
 INSERT INTO `t1` VALUES (1,0,0,700),(1,1,1,400),(1,5,5,400),(1,12,12,400),(1,12,32,400),(4,12,32,400);
 CREATE TEMPORARY TABLE `t2` ( `id` int NOT NULL default '0', `pid` int NOT NULL default '0', `map` int NOT NULL default '0', `level` int NOT NULL default '0', `title` varchar(255) default NULL, PRIMARY KEY  (`id`,`pid`,`map`), KEY `level` (`level`), KEY `id` (`id`,`map`)) ENGINE=MyISAM ;
 INSERT INTO `t2` VALUES (6,5,12,7,'a'),(12,0,0,7,'a'),(12,1,0,7,'a'),(12,5,5,7,'a'),(12,5,12,7,'a');
--- error 1054
+--error ER_BAD_FIELD_ERROR
 SELECT b.sc FROM (SELECT (SELECT a.access FROM t1 a WHERE a.map = op.map AND a.slave = op.pid AND a.master = 1) ac FROM t2 op WHERE op.id = 12 AND op.map = 0) b;
 SELECT b.ac FROM (SELECT (SELECT a.access FROM t1 a WHERE a.map = op.map AND a.slave = op.pid AND a.master = 1) ac FROM t2 op WHERE op.id = 12 AND op.map = 0) b;
 drop tables t1,t2;
@@ -1411,11 +1411,11 @@
 --echo # Comparison subquery and row with nested rows
 --echo #
 create temporary table t1 (a integer, b integer) ENGINE=MyISAM;
--- error 1241
+--error ER_OPERAND_COLUMNS
 select row(1,(2,2)) in (select * from t1 );
--- error 1241
+--error ER_OPERAND_COLUMNS
 select row(1,(2,2)) = (select * from t1 );
--- error 1241
+--error ER_OPERAND_COLUMNS
 select (select * from t1) = row(1,(2,2));
 drop table t1;
 
@@ -1424,12 +1424,12 @@
 --echo #
 create  table t1 (a integer);
 insert into t1 values (1);
--- error 1247
+--error ER_ILLEGAL_REFERENCE
 select 1 = ALL (select 1 from t1 where 1 = xx ), 1 as xx ;
--- error 1247
+--error ER_ILLEGAL_REFERENCE
 select 1 = ALL (select 1 from t1 where 1 = xx ), 1 as xx;
 select 1 as xx, 1 = ALL (  select 1 from t1 where 1 = xx );
--- error 1247
+--error ER_ILLEGAL_REFERENCE
 select 1 = ALL (select 1 from t1 where 1 = xx ), 1 as xx;
 drop table t1;
 
@@ -1551,17 +1551,17 @@
 --echo #
 create temporary table t1 (a int, b int) ENGINE=MyISAM;
 insert into t1 values (1,2);
--- error 1241
+--error ER_OPERAND_COLUMNS
 select 1 = (select * from t1);
--- error 1241
+--error ER_OPERAND_COLUMNS
 select (select * from t1) = 1;
--- error 1241
+--error ER_OPERAND_COLUMNS
 select (1,2) = (select a from t1);
--- error 1241
+--error ER_OPERAND_COLUMNS
 select (select a from t1) = (1,2);
--- error 1241
+--error ER_OPERAND_COLUMNS
 select (1,2,3) = (select * from t1);
--- error 1241
+--error ER_OPERAND_COLUMNS
 select (select * from t1) = (1,2,3);
 drop table t1;
 
@@ -2043,12 +2043,12 @@
        HAVING t1.a > ALL(SELECT t2.c FROM t2
                            WHERE EXISTS(SELECT t3.e FROM t3 GROUP BY t3.e
                                           HAVING SUM(t1.a+t2.c) < t3.e/4));
--- error 1111
+--error ER_INVALID_GROUP_FUNC_USE
 SELECT t1.a FROM t1 GROUP BY t1.a
        HAVING t1.a > ALL(SELECT t2.c FROM t2
                            WHERE EXISTS(SELECT t3.e FROM t3 
                                           WHERE SUM(t1.a+t2.c) < t3.e/4));
--- error 1111 
+--error ER_INVALID_GROUP_FUNC_USE 
 SELECT t1.a from t1 GROUP BY t1.a HAVING AVG(SUM(t1.b)) > 20;
 
 SELECT t1.a FROM t1 GROUP BY t1.a

